@@ -48,6 +48,12 @@ class EANSearch:
 		data = json.loads(contents)
 		return data["productlist"]
 
+	def categorySearch(self, category, name='', page=0, lang=99):
+		"""search for a product name"""
+		contents = self._urlopen(self._apiurl + "&op=category-search&category=" + str(category) + "&name=" + name + "&page=" + str(page) + "&language=" + str(lang))
+		data = json.loads(contents)
+		return data["productlist"]
+
 	def barcodePrefixSearch(self, prefix, page=0, lang=1):
 		"""search for a prefix of EAN barcodes"""
 		contents = self._urlopen(self._apiurl + "&op=barcode-prefix-search&prefix=" + prefix + "&page=" + str(page) + "&language=" + str(lang))
@@ -57,8 +63,8 @@ class EANSearch:
 	def _urlopen(self, url):
          if (sys.version_info >= (3,)):
              import urllib.request
-             return urllib.request.urlopen(url).read().decode("utf-8")
+             return urllib.request.urlopen(url, timeout=180).read().decode("utf-8")
          else:
              import urllib2
-             return urllib2.urlopen(url).read().decode("utf-8")
+             return urllib2.urlopen(url, timeout=180).read().decode("utf-8")
 
